Crate tracing_profile_perfetto_sys
Source - EventData
- Represents a tracing event data.
- PerfettoGuard
- Create only one of these per tracing session. It should live for the duration of the program.
- TraceEvent
- Represents a tracing span. Will exist until the struct is dropped.
- BackendConfig
- Backend configuration for perfetto.
- Error
- create_instant_event
- Emit the given
EventData as a Perfetto instant event with all metadata. - set_counter_f64
- Update the value of a counter with a 64-bit floating point number.
- set_counter_u64
- Update the value of a counter with a 64-bit unsigned integer.